@@ -389,8 +389,9 @@ def load_stream_batch(
     if row_count[stream] > 0:
         flush_records(stream, records_to_load, row_count[stream], db_sync, temp_dir)
 
-    # Load finished, create indices if required
-    db_sync.create_indices(stream)
+    # NOTE(jwills): taking index creation out for now as it causes more headaches than it's
+    # worth for DuckDB; see https://github.com/duckdb/duckdb/issues/3265
+    # db_sync.create_indices(stream)
 
     # Delete soft-deleted, flagged rows - where _sdc_deleted at is not null
     if delete_rows:
