@@ -14,6 +14,7 @@ def camelize(string: str, uppercase_first_letter: bool = True) -> str:
     else:
         return string[0].lower() + camelize(string)[1:]
 
+
 # pylint: disable=fixme
 def column_type(schema_property):
     property_type = schema_property["type"]
@@ -40,7 +41,7 @@ def column_type(schema_property):
             elif schema_property["maximum"] <= 9223372036854775807:
                 col_type = "bigint"
         else:
-            col_type = "decimal"
+            col_type = "hugeint"
     elif "boolean" in property_type:
         col_type = "boolean"
 
@@ -64,9 +65,7 @@ def flatten_key(k, parent_key, sep):
     inflected_key = full_key.copy()
     reducer_index = 0
     while len(sep.join(inflected_key)) >= 63 and reducer_index < len(inflected_key):
-        reduced_key = re.sub(
-            r"[a-z]", "", camelize(inflected_key[reducer_index])
-        )
+        reduced_key = re.sub(r"[a-z]", "", camelize(inflected_key[reducer_index]))
         inflected_key[reducer_index] = (
             reduced_key if len(reduced_key) > 1 else inflected_key[reducer_index][0:3]
         ).lower()
@@ -337,7 +336,6 @@ class DbSync:
             for name in self.flatten_schema
         ]
 
-
     def load_rows(self, records, count):
         stream_schema_message = self.stream_schema_message
         stream = stream_schema_message["stream"]
@@ -352,7 +350,7 @@ class DbSync:
         insert_sql = "INSERT INTO {} ({}) VALUES ({})".format(
             temp_table,
             ", ".join(self.column_names()),
-            ", ".join(["?" for x in self.column_names()])
+            ", ".join(["?" for x in self.column_names()]),
         )
         self.logger.debug(insert_sql)
         for record in records:
@@ -388,7 +386,8 @@ class DbSync:
 
     def update_from_temp_table(self, temp_table):
         stream_schema_message = self.stream_schema_message
-        columns = self.column_names()
+        primary_key_columns = set(primary_column_names(self.stream_schema_message))
+        columns = [x for x in self.column_names() if x not in primary_key_columns]
         table = self.table_name(stream_schema_message["stream"])
 
         return """UPDATE {} SET {} FROM {} s
@@ -423,10 +422,14 @@ class DbSync:
             for (name, schema) in self.flatten_schema.items()
         ]
 
-        # TODO(jwills): bring this back once I fix https://github.com/duckdb/duckdb/issues/3265
-        # primary_key = ["PRIMARY KEY ({})".format(', '.join(primary_column_names(stream_schema_message)))] \
-        #    if len(stream_schema_message['key_properties']) > 0 else []
-        primary_key = []
+        if len(stream_schema_message["key_properties"]) > 0:
+            primary_key = [
+                "PRIMARY KEY ({})".format(
+                    ", ".join(primary_column_names(stream_schema_message))
+                )
+            ]
+        else:
+            primary_key = []
 
         if not table_name:
             gen_table_name = self.table_name(
